---
title: How to Secure Access to Your Mobile Devices
---

# How to Secure Access to Your Mobile Devices

* [Overview](#overview)
* [Android](#Android)
* [iOS](#ios)

## Overview

The first things you should do to secure your mobile device is to:

1. **Enable encryption**, and
1. **Enable screen locking** with a code or pattern
1. **Enable SIM card lock**

Newer iOS and Android devices feature multiple methods for locking your device, including a fingerprint (biometric) sensor. While fingerprint sensors are very convenient, it should be noted that **fingerprint sensors are easily defeated**. It's trivial for someone else to create a copy of your fingerprint, and it's also possible for someone to physically force you to unlock your device. There are a few strategies you can use to protect yourself from this, however, such as turning your phone off or temporarily disabling fingerprint unlock.

## Android

[Google has published a brief guide](https://support.google.com/pixelphone/answer/6172890) on securing your device.

### Enable Encryption

[Follow the official Google guide](https://support.google.com/nexus/answer/2844831) on enabling encryption. Note that newer versions of Android have encryption enabled by default.

### Enable Screen Locking

[Follow the official Google guide](https://support.google.com/nexus/answer/2819522) on enabling a screen lock. In addition to the Google guide, here's some recommendations:

* Use either a PIN, pattern, or password lock
* Don't use the same code or pattern for multiple devices
* Don't use a code or PIN you use somewhere else, such as a bank card PIN
* As noted above, fingerprint unlocking provides only superficial security
* Set the screen to lock automatically after 60 seconds or less

### Enable SIM Card Lock

[Follow the official Google guide](https://support.google.com/android-one/answer/6174402) on enabling the SIM card lock. _Note: this may not be necessary for services like Project Fi, and the SIM lock option may be missing from the device settings._

### Additional Precautions

If you find yourself in a situation where you are concerned about unauthorized access, such as a border crossing, it's recommended that you power off your device beforehand, or disable fingerprint unlock. When a device is powered on, it will require that you input a PIN, pattern, or password before allowing access.

[Android devices have a remote management feature](https://www.google.com/android/devicemanager), which can be used to lock or erase a device which has been lost, stolen, or otherwise compromised.

## iOS

[Apple has published a security guide for iOS](https://www.apple.com/business/docs/iOS_Security_Guide.pdf), which contains a lot of detail about iOS's security features.

### Enable Encryption

[The EFF publishes a guide](https://ssd.eff.org/en/module/how-encrypt-your-iphone) on enabling encryption. Note that newer versions of iOS have encryption enabled by default. Furthermore, some content may still be extracted from an iOS device even with encryption enabled due to the [existence of backdoors created for law enforcement agencies](https://web.archive.org/web/20140902203916/http://www.apple.com/legal/more-resources/law-enforcement/  ).

### Enable Screen Locking

[Follow the official Apple guide](https://support.apple.com/en-us/HT204060) on enabling a screen lock. In addition to the Google guide, here's some recommendations:

* Use a passcode
* Don't use the same code for multiple devices
* Don't use a code or PIN you use somewhere else, such as a bank card PIN
* As noted above, fingerprint unlocking provides only superficial security

### Enable SIM Card Lock

[Follow the official Apple guide](https://support.apple.com/en-us/HT201529) on enabling the SIM card lock.

### Additional Precautions

If you find yourself in a situation where you are concerned about unauthorized access, such as a border crossing, it's recommended that you power off your device beforehand, or disable fingerprint unlock. When a device is powered on, it will require that you input a PIN, pattern, or password before allowing access.

[iOS devices have a remote management feature](https://www.icloud.com/find), which can be used to lock or erase a device which has been lost, stolen, or otherwise compromised.
